@@ -43,7 +43,6 @@
 #include "games-pause-action.h"
 #include "games-fullscreen-action.h"
 #include "games-scores.h"
-#include "games-stock.h"
 
 #include <clutter-gtk/clutter-gtk.h>
 #include <clutter/clutter.h>
@@ -74,8 +73,6 @@ static const GamesScoresCategory scorecats[] = {
 
 GamesScores *highscores;
 
-extern GdkPixbuf *logo_pixmap;
-
 GnibblesProperties *properties;
 
 GnibblesBoard *board;
@@ -98,9 +95,7 @@ gint current_level;
 
 static gint add_bonus_cb (gpointer data);
 
-static void render_logo (void);
 static gint end_game_cb (GtkAction * action, gpointer data);
-static void hide_logo (void);
 
 static GtkAction *new_game_action;
 GtkAction *pause_action;
@@ -109,8 +104,6 @@ static GtkAction *preferences_action;
 static GtkAction *scores_action;
 static GtkAction *fullscreen_action;
 
-static ClutterActor *logo;
-
 static void
 hide_cursor (void)
 {
@@ -158,24 +151,23 @@ about_cb (GtkAction * action, gpointer data)
                              "Guillaume Beland", NULL };
 
   const gchar *documenters[] = { "Kevin Breit", NULL };
-  gchar *license = games_get_license (_("Nibbles"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
        "program-name", _("Nibbles"),
        "version", VERSION,
        "copyright",
-       "Copyright \xc2\xa9 1999-2008 Sean MacIsaac, Ian Peters, Andreas Røsdal"
-       " 2009 Guillaume Beland",
-       "license", license, "comments",
-       _("A worm game for GNOME.\n\nNibbles is a part of GNOME Games."),
+       "Copyright \xc2\xa9 1999-2008 Sean MacIsaac, Ian Peters, Andreas Røsdal\n"
+       "Copyright \xc2\xa9 2009 Guillaume Beland",
+
+       "license-type", GTK_LICENSE_GPL_2_0, 
+       "comments", _("A worm game for GNOME.\n\nNibbles is a part of GNOME Games."),
        "authors", authors,
-       "documenters", documenters, "translator-credits",
-       _("translator-credits"), "logo-icon-name",
-       "gnome-nibbles", "website",
-       "http://www.gnome.org/projects/gnome-games/",
+       "documenters", documenters, 
+       "translator-credits", _("translator-credits"), 
+       "logo-icon-name", "gnome-nibbles", 
+       "website", "http://www.gnome.org/projects/gnome-games/",
        "website-label", _("GNOME Games web site"),
        "wrap-license", TRUE, NULL);
-  g_free (license);
 }
 
 static gboolean
@@ -205,15 +197,17 @@ configure_event_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
     ts_y--;
   tilesize = MIN (ts_x, ts_y);
 
-  gnibbles_load_pixmap (tilesize);
-  gnibbles_load_logo (tilesize);
+  if(tilesize != properties->tilesize)
+  {	
+    gnibbles_load_pixmap (tilesize);
 
-  clutter_actor_set_size (CLUTTER_ACTOR (stage),
+    clutter_actor_set_size (CLUTTER_ACTOR (stage),
                           BOARDWIDTH * tilesize,
                           BOARDHEIGHT * tilesize);
-  if (game_running ()) {
-    if (board) {
-      gnibbles_board_rescale (board, tilesize);
+
+    gnibbles_board_rescale (board, tilesize);
+
+    if (game_running ()) {
       gnibbles_boni_rescale (boni, tilesize);
 
       for (i=0; i<properties->numworms; i++)
@@ -222,26 +216,11 @@ configure_event_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
       if (warpmanager)
         gnibbles_warpmanager_rescale (warpmanager, tilesize);
     }
-  } else {
-    if (logo)
-      hide_logo ();
 
-    if (board)
-      gnibbles_board_rescale (board, tilesize);
-
-    render_logo ();
+    properties->tilesize = tilesize;
+    gnibbles_properties_set_tile_size (tilesize);
   }
 
-  /* But, has the tile size changed? */
-  if (properties->tilesize == tilesize) {
-    /* We must always re-load the logo. */
-    gnibbles_load_logo (tilesize);
-    return FALSE;
-  }
-
-  properties->tilesize = tilesize;
-  gnibbles_properties_set_tile_size (tilesize);
-
   return FALSE;
 }
 
@@ -275,10 +254,10 @@ new_game (void)
   int i;
   gtk_action_set_sensitive (pause_action, TRUE);
   gtk_action_set_sensitive (end_game_action, TRUE);
-  gtk_action_set_sensitive (preferences_action, TRUE);
+  gtk_action_set_sensitive (new_game_action, FALSE);
+  gtk_action_set_sensitive (preferences_action, FALSE);
 
   if (game_running ()) {
-    end_game (FALSE);
     main_id = 0;
   }
 
@@ -288,14 +267,13 @@ new_game (void)
     current_level = rand () % MAXLEVEL + 1;
   }
 
-  hide_logo ();
   gnibbles_init ();
   gnibbles_board_level_new (board, current_level);
   gnibbles_board_level_add_bonus (board, 1);
 
   for (i = 0; i < properties->numworms; i++) {
     if (!clutter_actor_get_stage (worms[i]->actors))
-      clutter_container_add_actor (CLUTTER_CONTAINER (stage), worms[i]->actors);
+      clutter_actor_add_child (stage, worms[i]->actors);
     gnibbles_worm_show (worms[i]);
   }
 
@@ -349,14 +327,8 @@ pause_game_cb (GtkAction * action, gpointer data)
   }
 }
 
-static void
-show_scores_cb (GtkAction * action, gpointer data)
-{
-  gnibbles_show_scores (window, 0);
-}
-
 void
-end_game (gboolean show_splash)
+end_game (void)
 {
   if (main_id) {
     g_source_remove (main_id);
@@ -383,12 +355,12 @@ end_game (gboolean show_splash)
     restart_id = 0;
   }
 
-  if (show_splash) {
-    render_logo ();
-    gtk_action_set_sensitive (pause_action, FALSE);
-    gtk_action_set_sensitive (end_game_action, FALSE);
-    gtk_action_set_sensitive (preferences_action, TRUE);
-  }
+  animate_end_game ();
+
+  gtk_action_set_sensitive (pause_action, FALSE);
+  gtk_action_set_sensitive (end_game_action, FALSE);
+  gtk_action_set_sensitive (new_game_action, TRUE);
+  gtk_action_set_sensitive (preferences_action, TRUE);
 
   games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), FALSE);
 }
@@ -396,7 +368,7 @@ end_game (gboolean show_splash)
 static gboolean
 end_game_cb (GtkAction * action, gpointer data)
 {
-  end_game (TRUE);
+  end_game ();
   return FALSE;
 }
 
@@ -417,7 +389,7 @@ restart_game (gpointer data)
 
   for (i = 0; i < properties->numworms; i++) {
     if (!clutter_actor_get_stage (worms[i]->actors))
-      clutter_container_add_actor (CLUTTER_CONTAINER (stage), worms[i]->actors);
+      clutter_actor_add_child (stage, worms[i]->actors);
     gnibbles_worm_show (worms[i]);
   }
 
@@ -430,45 +402,46 @@ restart_game (gpointer data)
   return FALSE;
 }
 
-static void
-end_game_anim_cb (ClutterAnimation *animation, ClutterActor *actor)
-{
-  if (!restart_id)
-    end_game (TRUE);
-}
-
-static void
+void
 animate_end_game (void)
 {
   int i;
   for (i = 0; i < properties->numworms; i++) {
-    clutter_actor_animate (worms[i]->actors, CLUTTER_EASE_IN_QUAD, 500,
-                           "opacity", 0,
-                           "scale-x", 0.4, "scale-y", 0.4,
-                           "fixed::scale-center-x",
-                           (gfloat) worms[i]->xhead * properties->tilesize,
-                           "fixed::scale-center-y",
-                           (gfloat) worms[i]->yhead * properties->tilesize,
-                           NULL);
+    clutter_actor_save_easing_state(worms[i]->actors);
+    clutter_actor_set_easing_mode (worms[i]->actors, CLUTTER_EASE_IN_QUAD);
+    clutter_actor_set_easing_duration (worms[i]->actors, 500);
+    clutter_actor_set_scale (worms[i]->actors, 0.4, 0.4);
+    clutter_actor_set_opacity (worms[i]->actors, 0);
+    clutter_actor_restore_easing_state(worms[i]->actors);
   }
 
   for ( i = 0; i < boni->numbonuses; i++) {
-    clutter_actor_animate (boni->bonuses[i]->actor, CLUTTER_EASE_IN_QUAD, 500,
-                           "opacity", 0,
-                           "scale-x", 0.4, "scale-y", 0.4,
-                           "fixed::scale-gravity", CLUTTER_GRAVITY_CENTER,
-                           NULL);
-
+    clutter_actor_save_easing_state(boni->bonuses[i]->actor);
+    clutter_actor_set_easing_mode (boni->bonuses[i]->actor, CLUTTER_EASE_IN_QUAD);
+    clutter_actor_set_easing_duration (boni->bonuses[i]->actor, 500);
+    clutter_actor_set_scale (boni->bonuses[i]->actor, 0.4, 0.4);
+    clutter_actor_set_pivot_point (boni->bonuses[i]->actor,.5,.5);
+    clutter_actor_set_opacity (boni->bonuses[i]->actor, 0);
+    clutter_actor_restore_easing_state(boni->bonuses[i]->actor);
   }
 
-  g_signal_connect_after (
-    clutter_actor_animate (board->level, CLUTTER_EASE_IN_QUAD, 700,
-                           "scale-x", 0.4, "scale-y", 0.4,
-                           "fixed::scale-gravity", CLUTTER_GRAVITY_CENTER,
-                           "opacity", 0,
-                           NULL),
-    "completed", G_CALLBACK (end_game_anim_cb), NULL);
+  for ( i = 0; i < warpmanager->numwarps; i++) {
+    clutter_actor_save_easing_state(warpmanager->warps[i]->actor);
+    clutter_actor_set_easing_mode (warpmanager->warps[i]->actor, CLUTTER_EASE_IN_QUAD);
+    clutter_actor_set_easing_duration (warpmanager->warps[i]->actor, 500);
+    clutter_actor_set_scale (warpmanager->warps[i]->actor, 0.4, 0.4);
+    clutter_actor_set_pivot_point (warpmanager->warps[i]->actor,.5,.5);
+    clutter_actor_set_opacity (warpmanager->warps[i]->actor, 0);
+    clutter_actor_restore_easing_state(warpmanager->warps[i]->actor);
+  }
 
+  clutter_actor_save_easing_state(board->level);
+  clutter_actor_set_easing_mode (board->level, CLUTTER_EASE_IN_QUAD);
+  clutter_actor_set_easing_duration (board->level, 700);
+  clutter_actor_set_scale (board->level, 0.4, 0.4);
+  clutter_actor_set_pivot_point (board->level,.5,.5);
+  clutter_actor_set_opacity (board->level, 0);
+  clutter_actor_restore_easing_state(board->level);
 }
 
 gboolean
@@ -482,7 +455,7 @@ main_loop (gpointer data)
   gnibbles_scoreboard_update (scoreboard);
 
   if (status == VICTORY) {
-    end_game (TRUE);
+    end_game ();
     winner = gnibbles_get_winner ();
 
     if (winner == -1)
@@ -605,16 +578,14 @@ static const GtkActionEntry action_entry[] = {
   {"ViewMenu", NULL, N_("_View")},
   {"SettingsMenu", NULL, N_("_Settings")},
   {"HelpMenu", NULL, N_("_Help")},
-  {"NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL,
+  {"NewGame", NULL, N_("_New Game"), NULL, NULL,
    G_CALLBACK (new_game_cb)},
-  {"EndGame", GAMES_STOCK_END_GAME, NULL, NULL, NULL,
+  {"EndGame", NULL, N_("_End Game"), NULL, NULL,
    G_CALLBACK (end_game_cb)},
-  {"Scores", GAMES_STOCK_SCORES, NULL, NULL, NULL,
-   G_CALLBACK (show_scores_cb)},
   {"Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (quit_cb)},
   {"Preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL,
    G_CALLBACK (gnibbles_preferences_cb)},
-  {"Contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL, G_CALLBACK (help_cb)},
+  {"Contents", NULL, N_("_Contents"), NULL, NULL, G_CALLBACK (help_cb)},
   {"About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_cb)}
 };
 
@@ -627,8 +598,6 @@ static const char ui_description[] =
   "      <separator/>"
   "      <menuitem action='Pause'/>"
   "      <separator/>"
-  "      <menuitem action='Scores'/>"
-  "      <separator/>"
   "      <menuitem action='Quit'/>"
   "    </menu>"
   "    <menu action='ViewMenu'>"
@@ -687,7 +656,7 @@ setup_window (void)
   clutter_widget = gtk_clutter_embed_new ();
   stage = gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (clutter_widget));
 
-  clutter_stage_set_color (CLUTTER_STAGE(stage), &stage_color);
+  clutter_actor_set_background_color (stage, &stage_color);
 
   clutter_actor_set_size (CLUTTER_ACTOR (stage),
                           properties->tilesize * BOARDWIDTH,
@@ -711,7 +680,6 @@ setup_window (void)
 
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
-  games_stock_init ();
   ui_manager = gtk_ui_manager_new ();
   create_menus (ui_manager);
   notebook = gtk_notebook_new ();
@@ -750,139 +718,6 @@ setup_window (void)
   scoreboard = gnibbles_scoreboard_new (statusbar);
 }
 
-static void
-render_logo (void)
-{
-  ClutterActor *image;
-  ClutterActor *text, *text_shadow;
-  ClutterActor *desc, *desc_shadow;
-  ClutterColor actor_color = {0xff,0xff,0xff,0xff};
-  ClutterColor shadow_color = {0x00, 0x00, 0x00, 0x88};
-  ClutterActor *text_group;
-  static gint width, height;
-  gint size;
-  gfloat stage_w, stage_h;
-  PangoFontDescription *pfd;
-  PangoLayout *layout;
-  PangoContext *context;
-  GError *error = NULL;
-
-  gchar *nibbles = _("Nibbles");
-  /* Translators: This string will be included in the intro screen, so don't make sure it fits! */
-  gchar *description = _("A worm game for GNOME.");
-
-  logo = clutter_group_new ();
-  text_group = clutter_group_new ();
-
-  if (!logo_pixmap)
-    gnibbles_load_logo (properties->tilesize);
-
-  image = gtk_clutter_texture_new ();
-  gtk_clutter_texture_set_from_pixbuf (GTK_CLUTTER_TEXTURE (image), logo_pixmap, &error);
-
-  stage_w = board->width * properties->tilesize;
-  stage_h = board->height * properties->tilesize;
-
-  clutter_actor_set_size (CLUTTER_ACTOR (image), stage_w, stage_h);
-
-  clutter_actor_set_position (CLUTTER_ACTOR (image), 0, 0);
-  clutter_actor_show (image);
-
-  text = clutter_text_new ();
-  clutter_text_set_color (CLUTTER_TEXT (text), &actor_color);
-
-  context = gdk_pango_context_get ();
-  layout = clutter_text_get_layout (CLUTTER_TEXT (text));
-  pfd = pango_context_get_font_description (context);
-  size = pango_font_description_get_size (pfd);
-
-  pango_font_description_set_size (pfd, (size * stage_w) / 100);
-  pango_font_description_set_family (pfd, "Sans");
-  pango_font_description_set_weight(pfd, PANGO_WEIGHT_BOLD);
-  pango_layout_set_font_description (layout, pfd);
-  pango_layout_set_text (layout, nibbles, -1);
-  pango_layout_get_pixel_size (layout, &width, &height);
-
-  text_shadow = clutter_text_new ();
-  clutter_text_set_color (CLUTTER_TEXT (text_shadow), &shadow_color);
-
-  layout = clutter_text_get_layout (CLUTTER_TEXT (text_shadow));
-  pango_layout_set_font_description (layout, pfd);
-  pango_layout_set_text (layout, nibbles, -1);
-
-  clutter_actor_set_position (CLUTTER_ACTOR (text),
-                              (stage_w - width) * 0.5 ,
-                              stage_h * .72);
-  clutter_actor_set_position (CLUTTER_ACTOR (text_shadow),
-                              (stage_w - width) * 0.5 + 5,
-                              stage_h * .72 + 5);
-
-  desc = clutter_text_new ();
-  layout = clutter_text_get_layout (CLUTTER_TEXT (desc));
-
-  clutter_text_set_color (CLUTTER_TEXT (desc), &actor_color);
-  pango_font_description_set_size (pfd, (size * stage_w) / 400);
-  pango_layout_set_font_description (layout, pfd);
-  pango_layout_set_text (layout, description, -1);
-  pango_layout_get_pixel_size(layout, &width, &height);
-
-  desc_shadow = clutter_text_new ();
-  layout = clutter_text_get_layout (CLUTTER_TEXT (desc_shadow));
-  clutter_text_set_color (CLUTTER_TEXT (desc_shadow), &shadow_color);
-
-  pango_font_description_set_size (pfd, (size * stage_w) / 400);
-  pango_layout_set_font_description (layout, pfd);
-  pango_layout_set_text (layout, description, -1);
-
-  clutter_actor_set_position (CLUTTER_ACTOR (desc),
-                              (stage_w - width) * 0.5,
-                              stage_h* .93);
-  clutter_actor_set_position (CLUTTER_ACTOR (desc_shadow),
-                              (stage_w - width) * 0.5 + 3,
-                              stage_h * .93 + 3);
-
-  clutter_container_add (CLUTTER_CONTAINER (text_group),
-                         CLUTTER_ACTOR (text_shadow),
-                         CLUTTER_ACTOR (text),
-                         CLUTTER_ACTOR (desc_shadow),
-                         CLUTTER_ACTOR (desc),
-                         NULL);
-  clutter_container_add (CLUTTER_CONTAINER (logo),
-                         CLUTTER_ACTOR (image),
-                         CLUTTER_ACTOR (text_group),
-                         NULL);
-
-  clutter_actor_set_opacity (CLUTTER_ACTOR (text_group), 0);
-  clutter_actor_set_scale (CLUTTER_ACTOR (text_group), 0.0, 0.0);
-  clutter_actor_animate (text_group, CLUTTER_EASE_OUT_CIRC, 800,
-                          "opacity", 0xff,
-                          "scale-x", 1.0,
-                          "scale-y", 1.0,
-                          "fixed::scale-center-y", stage_w / 2,
-                          "fixed::scale-center-x", stage_h / 2,
-                          NULL);
-
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage),
-                               CLUTTER_ACTOR (logo));
-}
-
-static void
-on_hide_logo_completed (ClutterAnimation *animation, ClutterActor *actor)
-{
-  clutter_actor_hide (actor);
-  clutter_group_remove_all (CLUTTER_GROUP (actor));
-}
-
-static void
-hide_logo (void)
-{
-  g_signal_connect_after (
-    clutter_actor_animate (logo, CLUTTER_EASE_IN_QUAD, 150,
-                           "opacity", 0,
-                           NULL),
-    "completed", G_CALLBACK (on_hide_logo_completed), logo);
-}
-
 int
 main (int argc, char **argv)
 {
@@ -896,7 +731,11 @@ main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  games_scores_startup ();
+  /*
+   * Required because the binary doesn't match the desktop file.
+   * Has to be before the call to g_option_context_parse.
+   */
+  g_set_prgname ("gnibbles");
 
   g_set_application_name (_("Nibbles"));
 
@@ -944,7 +783,6 @@ main (int argc, char **argv)
   properties = gnibbles_properties_new ();
   setup_window ();
   gnibbles_load_pixmap (properties->tilesize);
-  gnibbles_load_logo (properties->tilesize);
 
   gtk_action_set_sensitive (pause_action, FALSE);
   gtk_action_set_sensitive (end_game_action, FALSE);
