@@ -80,8 +80,6 @@ start_level_cb (GtkWidget * widget, gpointer data)
   if (!pref_dialog)
     return;
 
-  end_game (FALSE);
-
   level = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data));
   gnibbles_properties_set_start_level (level);
 }
@@ -222,7 +220,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   GtkWidget *controls;
   gchar *buffer;
   gint i;
-  gint running = 0;
 
   if (pref_dialog) {
     gtk_window_present (GTK_WINDOW (pref_dialog));
@@ -234,9 +231,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
     gtk_action_activate (pause_action);
   }
 
-  if (game_running ())
-    running = 1;
-
   pref_dialog = gtk_dialog_new_with_buttons (_("Nibbles Preferences"),
                                              GTK_WINDOW (window), 0,
                                              GTK_STOCK_CLOSE,
@@ -325,8 +319,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
     gtk_check_button_new_with_mnemonic (_("_Play levels in random order"));
   gtk_box_pack_start (GTK_BOX (vbox_options), button, FALSE, FALSE, 0);
 
-  if (running)
-    gtk_widget_set_sensitive (button, FALSE);
   if (properties->random)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
   g_signal_connect (GTK_WIDGET (button), "toggled", G_CALLBACK
@@ -335,8 +327,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   button = gtk_check_button_new_with_mnemonic (_("_Enable fake bonuses"));
   gtk_box_pack_start (GTK_BOX (vbox_options), button, FALSE, FALSE, 0);
 
-  if (running)
-    gtk_widget_set_sensitive (button, FALSE);
   if (properties->fakes)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
   g_signal_connect (GTK_WIDGET (button), "toggled", G_CALLBACK
@@ -362,8 +352,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
 
   if (properties->random)
     gtk_widget_set_sensitive (GTK_WIDGET (label2), FALSE);
-  if (running)
-    gtk_widget_set_sensitive (GTK_WIDGET (label2), FALSE);
   gtk_widget_set_hexpand (label2, TRUE);
   gtk_grid_attach (GTK_GRID (grid2), label2, 0, 0, 1, 1);
 
@@ -378,8 +366,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
 
   if (properties->random)
     gtk_widget_set_sensitive (GTK_WIDGET (levelspinner), FALSE);
-  if (running)
-    gtk_widget_set_sensitive (GTK_WIDGET (levelspinner), FALSE);
   gtk_grid_attach (GTK_GRID (grid2), levelspinner, 1, 0, 1, 1);
   g_signal_connect (GTK_ADJUSTMENT (adjustment), "value_changed",
                     G_CALLBACK (start_level_cb), levelspinner);
@@ -389,8 +375,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
 
   gtk_widget_set_hexpand (label2, TRUE);
   gtk_grid_attach (GTK_GRID (grid2), label2, 0, 1, 1, 1);
-  if (running)
-    gtk_widget_set_sensitive (label2, FALSE);
 
   adjustment = gtk_adjustment_new ((gfloat) properties->human, 0.0,
                                    NUMWORMS, 1.0, 1.0, 0.0);
@@ -400,8 +384,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), num_human);
 
   gtk_grid_attach (GTK_GRID (grid2), num_human, 1, 1, 1, 1);
-  if (running)
-    gtk_widget_set_sensitive (num_human, FALSE);
   g_signal_connect (GTK_ADJUSTMENT (adjustment), "value_changed",
                     G_CALLBACK (num_worms_cb), num_human);
 
@@ -410,8 +392,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
 
   gtk_widget_set_hexpand (label2, TRUE);  
   gtk_grid_attach (GTK_GRID (grid2), label2, 0, 2, 1, 1);
-  if (running)
-    gtk_widget_set_sensitive (label2, FALSE);
 
   adjustment = gtk_adjustment_new ((gfloat) properties->ai, 0.0,
                                    NUMWORMS, 1.0, 1.0, 0.0);
@@ -421,8 +401,6 @@ gnibbles_preferences_cb (GtkWidget * widget, gpointer data)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), num_ai);
 
   gtk_grid_attach (GTK_GRID (grid2), num_ai, 1, 2, 1, 1);
-  if (running)
-    gtk_widget_set_sensitive (num_ai, FALSE);
   g_signal_connect (GTK_ADJUSTMENT (adjustment), "value_changed",
                     G_CALLBACK (num_worms_cb), num_ai);
 
